==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/compton-conf/compton-conf_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Ustawienia efektów specjalnych</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Cień</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="30"/>
        <source>The blur radius for shadows</source>
        <translation>Promień rozmycia cienia</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="40"/>
        <source>The left offset for shadows</source>
        <translation>Przesunięcie cienia w lewo</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="54"/>
        <source>The top offset for shadows</source>
        <translation>Przesunięcie cienia w górę</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="68"/>
        <source>The translucency for shadows</source>
        <translation>Widoczność cienia</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="75"/>
        <source>Color of shadow</source>
        <translation>Kolor cienia</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="89"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Napraw częste problemy z oknami ARGB</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="92"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Wyczyść cienie znajdujące się poza oknem</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="99"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Nie wyświetlaj cienia podczas przemieszczania okien</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="106"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Unikaj wyświetlania cienia przy zadokowanych oknach i panelach</translation>
    </message>
    <message>
        <source>Enabled client-side shadows on windows</source>
        <translation type="vanished">Włącz cienie okien od strony klienta</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="113"/>
        <source>Enable client-side shadows on windows</source>
        <translation>Włącz cienie okien od strony klienta</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="120"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Unikaj wyświetlania cienia przy nieprostokątnych oknach</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="138"/>
        <source>Opacity</source>
        <translation>Widoczność</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="147"/>
        <source>The opacity for menus</source>
        <translation>Widoczność menu</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="154"/>
        <source>Default opacity of inactive windows</source>
        <translation>Domyślna widoczność nieaktywnych okien</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="161"/>
        <source>Default opacity for active windows</source>
        <translation>Domyślna widoczność aktywnych okien</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="168"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Widoczność obramowania okien</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="175"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>Back-end XRender: rozmiar kroku dla zasobów przezroczystych
(Jego zwiększenie może skutkować mniejszym użyciem zasobów X)</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="183"/>
        <source>Dim inactive windows</source>
        <translation>Przyciemniaj nieaktywne okna</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="190"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Nie pozwalaj dostosować przyciemnienia na podstawie widoczności okna</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="197"/>
        <source>Blur background of transparent windows</source>
        <translation>Rozmywaj tło przezroczystych okien</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="204"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Rozmywaj też tło widocznych okien z przezroczystymi ramkami</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="211"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Nie pozwól, aby promień rozmycia był zależny od widoczności okien</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="279"/>
        <source>Fade</source>
        <translation>Przenikanie</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="285"/>
        <source>Fade windows during opacity changes</source>
        <translation>Przenikaj okna w trakcie zmiany widoczności</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="292"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Czas w milisekundach pomiędzy krokami w trakcie przenikania</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="299"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Zmiana widoczności pojawiającego się okna pomiędzy krokami</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="306"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Zmiana widoczności zanikającego okna pomiędzy krokami</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="313"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Unikaj przenikania okien podczas otwierania i zamykania</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="356"/>
        <source>Other</source>
        <translation>Inne</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="368"/>
        <source>Rendering backend</source>
        <translation>Back-end renderowania</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="380"/>
        <source>X Render</source>
        <translation>X Render</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="387"/>
        <source>GLX (OpenGL)</source>
        <translation>GLX (OpenGL)</translation>
    </message>
    <message>
        <source>Not implemented yet</source>
        <translation type="vanished">Nie zaimplementowano</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="403"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="206"/>
        <source>About ComptonConf</source>
        <translation>O ComptonConf</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="207"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - narzędzie konfiguracyjne dla Comptona

Prawa autorskie (C) 2013
Autor: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/compton-conf/compton-conf_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Ustawienia efektów specjalnych</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Cień</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="67"/>
        <source>The blur radius for shadows</source>
        <translation>Promień rozmycia cienia</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="77"/>
        <source>The left offset for shadows</source>
        <translation>Przesunięcie cienia w lewo</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="91"/>
        <source>The top offset for shadows</source>
        <translation>Przesunięcie cienia w górę</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="105"/>
        <source>The translucency for shadows</source>
        <translation>Widoczność cienia</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="122"/>
        <source>Color of shadow</source>
        <translation>Kolor cienia</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="57"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Napraw częste problemy z oknami ARGB</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="60"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Wyczyść cienie znajdujące się poza oknem</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="50"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Nie wyświetlaj cienia podczas przemieszczania okien</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="43"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Unikaj wyświetlania cienia przy zadokowanych oknach i panelach</translation>
    </message>
    <message>
        <source>Enabled client-side shadows on windows</source>
        <translation type="vanished">Włącz cienie okien od strony klienta</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="36"/>
        <source>Enable client-side shadows on windows</source>
        <translation>Włącz cienie okien od strony klienta</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="136"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Unikaj wyświetlania cienia przy nieprostokątnych oknach</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="143"/>
        <source>Crop shadows of maximized windows from extended displays</source>
        <translation>Przycinaj cienie zmaksymalizowanych okien z dodatkowych ekranów</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="151"/>
        <source>Opacity</source>
        <translation>Widoczność</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="160"/>
        <source>The opacity for menus</source>
        <translation>Widoczność menu</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="167"/>
        <source>Default opacity of inactive windows</source>
        <translation>Domyślna widoczność nieaktywnych okien</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="174"/>
        <source>Default opacity for active windows</source>
        <translation>Domyślna widoczność aktywnych okien</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="181"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Widoczność obramowania okien</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="188"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>Back-end XRender: rozmiar kroku dla zasobów przezroczystych
(Jego zwiększenie może skutkować mniejszym użyciem zasobów X)</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="196"/>
        <source>Dim inactive windows</source>
        <translation>Przyciemniaj nieaktywne okna</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="203"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Nie pozwalaj dostosować przyciemnienia na podstawie widoczności okna</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="210"/>
        <source>Blur background of transparent windows</source>
        <translation>Rozmywaj tło przezroczystych okien</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="217"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Rozmywaj też tło widocznych okien z przezroczystymi ramkami</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="224"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Nie pozwól, aby promień rozmycia był zależny od widoczności okien</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="292"/>
        <source>Fade</source>
        <translation>Przenikanie</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="298"/>
        <source>Fade windows during opacity changes</source>
        <translation>Przenikaj okna w trakcie zmiany widoczności</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="305"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Czas w milisekundach pomiędzy krokami w trakcie przenikania</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="312"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Zmiana widoczności pojawiającego się okna pomiędzy krokami</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="319"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Zmiana widoczności zanikającego okna pomiędzy krokami</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="326"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Unikaj przenikania okien podczas otwierania i zamykania</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="369"/>
        <source>Other</source>
        <translation>Inne</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="381"/>
        <source>Rendering backend</source>
        <translation>Back-end renderowania</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="393"/>
        <source>X Render</source>
        <translation>X Render</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="400"/>
        <source>GLX (OpenGL)</source>
        <translation>GLX (OpenGL)</translation>
    </message>
    <message>
        <source>Not implemented yet</source>
        <translation type="vanished">Nie zaimplementowano</translation>
    </message>
    <message>
        <location filename="../../maindialog.ui" line="416"/>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="209"/>
        <source>About ComptonConf</source>
        <translation>O ComptonConf</translation>
    </message>
    <message>
        <location filename="../../maindialog.cpp" line="210"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - narzędzie konfiguracyjne dla Comptona

Prawa autorskie (C) 2013
Autor: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>
